Extended CaptureTB outpatient visit cost model with more covariates.
unitcost_extended.RdThis function loads a JAGSModel model object
using default covariates and priors. This can be used to
predict the total cost of a single outpatient visit at
a given facility or facilities via the predict method. This model
is not pre-fitted, so requires JAGS to be installed to fit and use.
Value
An object of class JAGSModel.
Details
Note that numerical covariates are centered. When making predictions
with the model, the function prepare_covariates() can be used
to transform raw variables using the correct centering values.